@@ -1,4 +1,5 @@
-var uglify = require('rollup-plugin-terser').terser;
+// uglify handles only es5 code, so this also acts as smoke test against shipping es2015+ syntax
+var uglify = require('rollup-plugin-uglify').uglify;
 var pkg = require('./package.json');
 
 var banner = '//  Ramda v' + pkg.version + '\n'
@@ -13,9 +14,9 @@ var config = {
   output: {
     format: 'umd',
     name: 'R',
-    exports: 'named'
+    exports: 'named',
+    banner: banner
   },
-  banner: banner,
   plugins: []
 };
 
@@ -26,8 +27,8 @@ if (process.env.NODE_ENV === 'production') {
         pure_getters: true,
         unsafe: true,
         unsafe_comps: true,
-        warnings: false
-      }
+      },
+      warnings: false
     })
   );
 }
