@@ -1,5 +1,5 @@
 import _curry2 from './internal/_curry2';
-
+import paths from './paths';
 
 /**
  * Retrieve the value at a given path.
@@ -13,22 +13,16 @@ import _curry2 from './internal/_curry2';
  * @param {Array} path The path to use.
  * @param {Object} obj The object to retrieve the nested property from.
  * @return {*} The data at `path`.
- * @see R.prop
+ * @see R.prop, R.nth
  * @example
  *
  *      R.path(['a', 'b'], {a: {b: 2}}); //=> 2
  *      R.path(['a', 'b'], {c: {b: 2}}); //=> undefined
+ *      R.path(['a', 'b', 0], {a: {b: [1, 2, 3]}}); //=> 1
+ *      R.path(['a', 'b', -2], {a: {b: [1, 2, 3]}}); //=> 2
  */
-var path = _curry2(function path(paths, obj) {
-  var val = obj;
-  var idx = 0;
-  while (idx < paths.length) {
-    if (val == null) {
-      return;
-    }
-    val = val[paths[idx]];
-    idx += 1;
-  }
-  return val;
+
+var path = _curry2(function path(pathAr, obj) {
+  return paths([pathAr], obj)[0];
 });
 export default path;
