@@ -1,4 +1,5 @@
 import _curry2 from './internal/_curry2';
+import path from './path';
 
 
 /**
@@ -22,15 +23,8 @@ import _curry2 from './internal/_curry2';
  *      fullName({last: 'Bullet-Tooth', age: 33, first: 'Tony'}); //=> 'Tony Bullet-Tooth'
  */
 var props = _curry2(function props(ps, obj) {
-  var len = ps.length;
-  var out = [];
-  var idx = 0;
-
-  while (idx < len) {
-    out[idx] = obj[ps[idx]];
-    idx += 1;
-  }
-
-  return out;
+  return  ps.map(function(p) {
+    return path([p], obj);
+  });
 });
 export default props;
